diff --git a/scintilla/src/Indicator.cxx b/scintilla/src/Indicator.cxx
index 9ea4024..8df2fda 100644
--- a/scintilla/src/Indicator.cxx
+++ b/scintilla/src/Indicator.cxx
@@ -22,6 +22,26 @@ void Indicator::Draw(Surface *surface, const PRectangle &rc, const PRectangle &r
 	surface->PenColour(fore);
 	int ymid = (rc.bottom + rc.top) / 2;
 	if (style == INDIC_SQUIGGLE) {
+#if 1
+		// Cap width at 4000 to avoid large allocations when mistakes made
+		int width = Platform::Minimum(4000, rc.right - rc.left);
+		RGBAImage image(width, 3, 0);
+		int rwidth = width - width % 4;
+		for (int x = 0; x < rwidth; x += 4) {
+			image.SetPixel(x+0, 2, fore, 255);
+			image.SetPixel(x+1, 1, fore, 255);
+			image.SetPixel(x+2, 0, fore, 255);
+			image.SetPixel(x+3, 1, fore, 255);
+		}
+		int y = 3;
+		switch(width%4){
+			case 3: image.SetPixel(width-3, --y, fore, 255);
+			case 2: image.SetPixel(width-2, --y, fore, 255);
+			case 1: image.SetPixel(width-1, --y, fore, 255);
+			default:;
+		}
+		surface->DrawRGBAImage(rc, image.GetWidth(), image.GetHeight(), image.Pixels());
+#else
 		surface->MoveTo(rc.left, rc.top);
 		int x = rc.left + 2;
 		int y = 2;
@@ -31,7 +51,19 @@ void Indicator::Draw(Surface *surface, const PRectangle &rc, const PRectangle &r
 			y = 2 - y;
 		}
 		surface->LineTo(rc.right, rc.top + y);	// Finish the line
+#endif
 	} else if (style == INDIC_SQUIGGLELOW) {
+#if 1
+		// Cap width at 4000 to avoid large allocations when mistakes made
+		int width = Platform::Minimum(4000, rc.right - rc.left);
+		RGBAImage image(width, 2, 0);
+		int y = 1;
+		for (int x = 0; x < width; x++) {
+			image.SetPixel(x+0, y, fore, 255);
+			y = 1 - y;
+		}
+		surface->DrawRGBAImage(rc, image.GetWidth(), image.GetHeight(), image.Pixels());
+#else
 		surface->MoveTo(rc.left, rc.top);
 		int x = rc.left + 3;
 		int y = 0;
@@ -42,6 +74,7 @@ void Indicator::Draw(Surface *surface, const PRectangle &rc, const PRectangle &r
 			x += 3;
 		}
 		surface->LineTo(rc.right, rc.top + y);	// Finish the line
+#endif
 	} else if (style == INDIC_TT) {
 		surface->MoveTo(rc.left, ymid);
 		int x = rc.left + 5;
